"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Gets a list of contributors to a file committed to github
 * @param owner Repository Owner
 * @param repo Name of repository
 * @param path File path relative to repository root
 * @returns Promise<Author[]>
 */
var getFileContributors = function (owner, repo, path) {
    var authors = [];
    var consumedAuthors = {};
    return fetch("https://api.github.com/repos/" + owner + "/" + repo + "/commits?path=" + path)
        .then(function (res) { return res.json(); })
        .then(function (commits) {
        commits.forEach(function (commit) {
            var id = commit.author.login;
            if (consumedAuthors[id]) {
                return;
            }
            consumedAuthors[id] = true;
            authors.push(commit.author);
        });
        return authors;
    });
};
exports.default = getFileContributors;
//# sourceMappingURL=index.js.map